embassy-stm32

Crates

git

Versions

stm32l152vc-a

Flavors

WWDG

Struct WWDG 

pub struct WWDG { /* private fields */ }
WWDG peripheral

Implementations

Source

impl WWDG

pub const unsafe fn steal() -> Peri<'static, Self>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.